FAQ
====

During development, how do I quickly empty my database and start afresh ?
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. code-block:: console

   $ dropdb vulnerablecode
   $ make postgres
